# Decentralised Discovery Link

> A decentralised communication network designed for data discovery applications, especially for healthcare data.

[![GitHub License](https://img.shields.io/github/license/firefox2100/dedi-link)](https://github.com/Firefox2100/dedi-link/blob/main/LICENSE) [![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=Firefox2100_dedi-link&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=Firefox2100_dedi-link) [![Coverage](https://sonarcloud.io/api/project_badges/measure?project=Firefox2100_dedi-link&metric=coverage)](https://sonarcloud.io/summary/new_code?id=Firefox2100_dedi-link) [![Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=Firefox2100_dedi-link&metric=vulnerabilities)](https://sonarcloud.io/summary/new_code?id=Firefox2100_dedi-link)
